<template>
    <div class="report-overview">
        <el-row :gutter="12">
            <el-col :span="6">
                <div class="search-label">文件名称：</div>
                <el-input v-model="params.querys[0].value" clearable suffix-icon="el-icon-search" placeholder="请输入资料名称"
                    style="width: 100%"></el-input>
            </el-col>
            <el-col :span="6">
                <div class="search-label">文件类型：</div>
                <el-select popper-class="big-search-popper" clearable v-model="params.querys[1].value"
                    placeholder="请选择文件类型" style="width: 100%">
                    <el-option v-for="item in fileTypeOptions" :key="item.id" :label="item.name" :value="item.value">
                    </el-option>
                </el-select>
            </el-col>
            <el-col :span="6" v-if="params.querys[1].value === '2'">
                <div class="search-label">获奖分类：</div>
                <dict-select :popperClass="`big-search-popper`" dictCode="hjfl" v-model="params.querys[2].value"
                    :hasDefaultOption="true" clearable style="width: 100%" placeholder="请选择获奖分类" />
            </el-col>
            <el-col :span="6" v-if="params.querys[1].value === '5'">
                <div class="search-label">模块类别：</div>
                <dict-select :popperClass="`big-search-popper`" dictCode="mklb" v-model="params.querys[3].value"
                    :hasDefaultOption="true" clearable style="width: 100%" placeholder="请选择模块类别" />
            </el-col>
            <el-col class="search-btn" :span="2">
                <div class="search-label"></div>
                <el-button class="download" type="primary" icon="el-icon-search" @click="getData(1)">查询</el-button>
            </el-col>
        </el-row>

        <div class="content-box">
            <div class="left-table">
                <el-table height="calc(100% - 30px)" ref="dataTable" :data="tableData" id="table-bigger-detail"
                    :element-loading-background="loadingColor" v-loading="tableLoading" class="dialog_table" border
                    style="width: 100%" :header-cell-style="{ 'text-align': 'center' }">
                    <el-table-column type="index" v-if="params.querys[1].value !== '6'" label="序号" align="center" width="100">
                    </el-table-column>
                    <el-table-column prop="order" v-else label="序号" align="center" width="100">
                    </el-table-column>
                    <el-table-column :prop="params.querys[1].value === '6' ? 'fileName' : 'profileName'" label="文件名称">
                    </el-table-column>
                    <el-table-column v-if="params.querys[1].value === '2'" prop="profileInnovationClassify" label="获奖分类"
                        align="center" width="200">
                        <template v-slot="{ row }">
                            {{ getDictName('hjfl', row.profileInnovationClassify) }}
                        </template>
                    </el-table-column>
                    <el-table-column v-if="params.querys[1].value === '5'" prop="profileModuleClassify" label="模块类别"
                        align="center" width="250">
                        <template v-slot="{ row }">
                            {{ getDictName('mklb', row.profileModuleClassify) }}
                        </template>
                    </el-table-column>
                    <!-- <el-table-column prop="createTime" align="center" label="上传时间" width="280">
                    </el-table-column> -->
                    <el-table-column prop="profileName" label="操作" align="center" width="220">
                        <template v-slot="{ row }">
                            <FileList :fileList="[row]"></FileList>
                        </template>
                    </el-table-column>
                </el-table>
                <pagenation class="pagenation" @currentChange="pageChange" :pageResult="params.pageBean"></pagenation>
            </div>
        </div>
    </div>
</template>

<script>
import FileList from '@/components/uploadFile/newFileList.vue'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/majorView.js'
import utils from '@/utils.js'
export default {
    name: 'reformDataBase',
    components: {
        pagenation,
        FileList,
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableLoading: false,
            fileLoading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'file_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'profile_Type_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'profile_Innovation_Classify_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'profile_Module_Classify_',
                        relation: 'AND',
                        value: '',
                    },

                ],
                sorter: []
            },
            tableData: [],
            fileTypeOptions: [],
            dataList: []
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.getData(1)
    },
    created() {
        let { type } = this.$route.query
        this.params.querys[1].value = type
        this.params.sorter = [
            {
                direction: type == 5 ? "ASC" : 'DESC',
                property: "create_Time_"
            }
        ]
        let data = utils.getDictItemsFromCache('sjk_wjlx')
        this.fileTypeOptions = data.slice(0, -1)
        this.$emit('searchDateChange')
    },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getData(page) {
            this.tableLoading = true
            this.params.pageBean.page = page
            if (this.params.querys[1].value === '6') {
                this.params.pageBean.pageSize = -1
            }
            apiList.getReformDataBase(this.params, res => {
                if (this.params.querys[1].value === '6') {
                    // this.tableData = res.rows
                    res.rows.forEach((item, index) => {
                        let periodStr = item.fileName.replace(/[^0-9]/ig, "")
                        item.year = periodStr.slice(0, 4)
                        item.period = periodStr.slice(4, periodStr.length)
                        // item.order = index + 1
                    })
                    let yearArr = Array.from(new Set(res.rows.map(item => item.year))).sort((a, b) => b - a)
                    let arr = yearArr.map(year => {
                        return res.rows.filter(item => item.year === year).sort((a, b) => b.period - a.period)
                    })
                    arr.forEach(item => {
                        this.dataList = [...this.dataList, ...item]
                    })
                    this.dataList.forEach((item, index) => {
                        item.order = index + 1
                    })
                    this.tableData = this.dataList.slice((page - 1) * 20, page * 20)
                    this.params.pageBean.pageSize = 20
                    this.params.pageBean.total = res.rows.length
                } else {
                    this.params.pageBean.total = res.total
                    this.tableData = res.rows
                }
                this.tableLoading = false
            })
        },
        pageChange(key) {
            if (this.params.querys[1].value === '6') {
                this.tableLoading = true
                setTimeout(() => {
                    this.$refs.dataTable.bodyWrapper.scrollTop = 0
                    this.tableData = this.dataList.slice((key - 1) * 20, key * 20)
                    this.tableLoading = false
                }, 1000)

            } else {
                this.getData(key)
            }
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/.file-item {
    border: none;
    justify-content: center;

    .file_name {
        display: none;
    }

    a {
        .el-link--inner {
            font-size: 18PX !important;
        }
    }

    &:hover {
        background: none;
        color: #fff;

        .file_name {
            color: #fff;
        }
    }
}

/deep/.el-collapse {
    border: none;
}

/deep/.el-collapse-item__wrap {
    background: transparent;
    border: none;
}

/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
    border-color: #245cf3;
    background: transparent;
    color: #fff;
    font-size: 18PX;
}

/deep/.el-table td.el-table__cell div {
    // background: transparent;
}

/deep/.el-table--enable-row-hover .el-table__body tr:hover>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.dialog_table.el-table tr:nth-of-type(2n + 1) {
    background: transparent;
}

/deep/.el-descriptions__body {
    background: transparent;
}

/deep/.el-collapse-item__header.is-active {
    border-bottom-color: transparent;
    background: transparent;
    color: #245cf3;
    font-size: 20px;
    font-weight: bold;
}

/deep/.el-collapse-item__header {
    background: transparent;
    color: #245cf3;
    font-size: 18PX !important;
    font-weight: bold;
    border: none;
}

/deep/.el-collapse-item__arrow {
    margin: 0;
    font-weight: bold;
}

/deep/.dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}

/deep/.el-table__body tr.current-row>td.el-table__cell {
    background: rgba(2, 115, 233, .5) !important;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    margin-bottom: 10PX;
}

/deep/.el-table th.el-table__cell.is-leaf,
/deep/.el-table td.el-table__cell {
    border-bottom: 1px solid #245cf3;
}

/deep/.el-table--border th,
/deep/.el-table--border td {
    border-right: 1px solid #245cf3 !important;

    &:nth-child(5) {
        border-right: none !important;
    }

    * {
        font-size: 18PX !important;
    }
}

/deep/.el-table--border th {
    &:nth-last-child(2) {
        border-right: none !important;
    }
}

/deep/.el-table--border::after,
/deep/.el-table::before {
    width: 0;
    height: 0;
}

/deep/.el-table tr,
/deep/.el-table thead tr,
/deep/.el-table thead tr th {
    background: transparent !important;
}

/deep/.el-table th.el-table__cell>.cell,
/deep/.el-table td>.cell {
    font-size: 18PX;
    color: #fff;
}

/deep/.el-table {
    background: transparent;
    border: 1px solid rgba(2, 115, 233, 0.5);
    margin-bottom: 10px;

    ::-webkit-scrollbar-thumb {
        background-color: #034eb0 !important;
    }

    ::-webkit-scrollbar-track {
        background: #01215a !important;
    }

    ::-webkit-scrollbar {
        width: 18px !important;
        background: #01215a !important;
    }
}

/deep/ .el-table th.gutter{
  display: none;
  width:0
}
/deep/ .el-table colgroup col[name='gutter']{
  display: none;
  width: 0;
}
/deep/ .el-table__body{
  width: 100% !important;
}

/deep/.el-table th.gutter {
    border: none !important;
    border-bottom: 1px solid #245cf3 !important;  
    background: transparent !important;
}
</style>
<style lang="scss" scoped>
.report-overview {
    width: 70%;
    height: 100%;
    margin: 5PX 0 0 15%;

    >.el-row {
        height: 60PX;
        margin-bottom: 20PX;

        .search-label {
            height: 20PX;
            font-size: 18PX;
            line-height: 20PX;
            margin-bottom: 5px;
        }

        .search-btn {
            /deep/.el-button {
                height: 40PX;

                >* {
                    font-size: 18PX;
                }
            }
        }

        /deep/.el-input__inner {
            color: #fff;
            font-size: 18PX;
            height: 40PX;
            box-sizing: border-box;
            background: transparent;
            border: 1px solid #114385;

            &::placeholder {
                color: #fff;
                font-size: 18PX !important;
            }

            &::-webkit-input-placeholder {
                font-size: 18PX !important;
            }
        }
    }

    .content-box {
        height: calc(100% - 80PX);
        display: flex;
        gap: 10PX;

        .left-table {
            width: 100%;
            height: 100%;
        }
    }

    /deep/ .el-select-dropdown__item {
        background-color: #0d57ac !important;
        color: rgba(230, 247, 255, 0.7);

        span {
            font-size: 14px;
        }
    }

    /deep/ .el-select-dropdown__list {
        padding: 0;
    }

    /deep/ .el-select-dropdown {
        border: solid 1px #0273e9;
        background-color: rgba(1, 47, 115, 0.6);
    }

    /deep/.el-select-dropdown__item.hover,
    /deep/ .el-select-dropdown__item:hover {
        background-color: #025ec0 !important;
    }

    /deep/.el-popper[x-placement^="bottom"] .popper__arrow::after {
        border-bottom-color: #0d57ac;
    }

    /deep/.el-popper[x-placement^="bottom"] .popper__arrow {
        border-bottom-color: #0273e9;
    }
}
</style>
